import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const render = data => {

  const svg = select('svg');

  const width = +svg.attr('width');
  const height = +svg.attr('height');
  
  const xValue = d => d.timestamp;
  
  const yValue = d => d.temperature;
  
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();

const xAxisG = g.append('g').call(xAxis)
  .attr('transform', `translate(0,${innerHeight})`);

xAxisG.select('.domain').remove();

const lineGenerator = line()
  .x(d => xScale(xValue(d)))
  .y(d => yScale(yValue(d)))
  .curve(curveBasis);

g.append('path')
    .attr('class', 'line-path')
    .attr('d', lineGenerator(data));
};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => {
    data.forEach(d => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
  });